pub struct Item(Item<Bls12>);Expand description
The type of the batch item. This is a newtype around a Groth16 verification item.
Tuple Fields
0: Item<Bls12>Implementations
Sourceimpl Item
impl Item
Sourcepub fn verify_single(
self,
pvk: &PreparedVerifyingKey<Bls12>,
) -> Result<(), VerificationError>
pub fn verify_single( self, pvk: &PreparedVerifyingKey<Bls12>, ) -> Result<(), VerificationError>
Convenience method to call a method on the inner value to perform non-batched verification.
Sourceimpl Item
impl Item
Sourcepub fn from_joinsplit(
joinsplit: &JoinSplit<Groth16Proof>,
joinsplit_pub_key: &VerificationKeyBytes,
) -> Result<Self, TransactionError>
pub fn from_joinsplit( joinsplit: &JoinSplit<Groth16Proof>, joinsplit_pub_key: &VerificationKeyBytes, ) -> Result<Self, TransactionError>
Converts a Sprout JoinSplit description and its associated public key into a
Groth16 verification Item.
Encodes the primary input for the JoinSplit proof statement as Bls12_381 base
field elements, to match [bellman::groth16::verify_proof()].
NB: [jubjub::Fq] is a type alias for [bls12_381::Scalar].
joinsplit_pub_key: the JoinSplit public validation key for this JoinSplit, from
the transaction. (All JoinSplits in a transaction share the same validation key.)
This is not yet officially documented; see the reference implementation: https://github.com/zcash/librustzcash/blob/0ec7f97c976d55e1a194a37b27f247e8887fca1d/zcash_proofs/src/sprout.rs#L152-L166 https://zips.z.cash/protocol/protocol.pdf#joinsplitdesc